==============================
Django Websocket Notifications
==============================

A Django application to deliver user notifications made with 
`django-snitch <https://github.com/marcosgabarda/django-snitch>`_ using WebSockets.
